@@ -16,15 +16,21 @@
 
 //! Parser for `FEEL` language.
 
-pub extern crate dmntk_feel;
+#![feature(test)]
+
+extern crate dmntk_feel;
 
 mod lalr;
 mod lexer;
 mod parser;
 
+#[cfg(test)]
+mod benches;
+
 #[cfg(test)]
 mod tests;
 
 pub use parser::{
-  parse_boxed_expression, parse_context, parse_longest_name, parse_name, parse_textual_expression, parse_textual_expressions, parse_unary_tests,
+  parse_boxed_expression, parse_context, parse_expression, parse_longest_name, parse_name, parse_textual_expression, parse_textual_expressions,
+  parse_unary_tests,
 };
