@@ -15,7 +15,7 @@
  */
 
 use super::accept;
-use crate::lalr::TokenType::StartTextualExpression;
+use crate::lalr::TokenType::{StartExpression, StartTextualExpression};
 use crate::parser::Parser;
 use dmntk_feel::{scope, Scope};
 
@@ -167,12 +167,7 @@ fn _0007() {
 fn _0008() {
   let scope = scope!();
   assert_eq!(
-    "ParserError: syntax error",
-    Parser::new(&scope, StartTextualExpression, "+1", false)
-      .parse()
-      .err()
-      .unwrap()
-      .to_string()
-      .as_str()
+    "ParserError: syntax error: +1",
+    Parser::new(&scope, StartExpression, "+1", false).parse().err().unwrap().to_string().as_str()
   );
 }
