@@ -14,22 +14,26 @@
  * SOFTWARE.
  */
 
-use super::{accept, empty_scope};
+use super::accept;
 use crate::lalr::TokenType::StartTextualExpression;
+use dmntk_feel::{scope, Scope};
 
 #[test]
-fn test_between_1() {
-  let scope = &mut empty_scope();
+fn _0001() {
+  let scope = scope!();
   accept(
-    scope,
+    &scope,
     StartTextualExpression,
     "50 between 30 and 70",
     r#"
-        Between
-          Numeric 50.
-          Numeric 30.
-          Numeric 70.
-      "#,
+       Between
+       ├─ Numeric
+       │  └─ `50.`
+       ├─ Numeric
+       │  └─ `30.`
+       └─ Numeric
+          └─ `70.`
+    "#,
     false,
   );
 }
